from .client import stats_client as sc
from ..conf import read
from pprint import pprint
import click

@click.command('push')
@click.option('--host/--no-host', is_flag=True, default=True, help="Push just info on host and keys")
@click.option('--project/--no-project', is_flag=True, default=True,
              help="Push just info on projects and apps")
@click.option('-d', '--directory', help="the directory of the project to be pushed", default=".")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production system")
@click.option('-v', '--verbose', is_flag=True, help="show each package pushed")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
def push_info(host, project, directory, settings, verbose, test):
    """Push info on remote server"""
    if host:
        data = read.get_server_info()
        sc.servers.add_or_update(data)

    if project:
        data = read.get_project_info(directory, test)
        sc.projects.add_or_update(data)

        apps = read.get_packages()
        project_name = data['name']
        for app, rel in apps.items():
            if verbose:
                print("{} - {}".format(app, rel[0]))
            app_data = {
                'project': project_name,
                'app': app,
                'version': rel[0],
                'egg': rel[1],
                }
            sc.appproject.add_or_update_by_slugs(project_name, app, app_data)

@click.command('show')
@click.option('-d', '--directory', help="the directory of the project to be pushed", default=".")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production sysm")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
def show(directory, settings, test):
    """Show all info that will be pushed"""
    data = {}
    data['server'] = read.get_server_info()

    data['project'] = read.get_project_info(directory, test)
    pprint(data)
